#

##

##

##

###

###

###

    	aphrodisiac

    	tags
    		# origin
    		# sex organ

    		# aphrodisiac
    		# pheromones

    	summary

    	objectives ranked

    		app level
    			[ ] turn on node
    			[ ] turn off node

    		app stuff
    			[ ] create key
    			[ ] sign
    			[ ] verify

    		B2B
    			[ ] coins that _____ has

    			[ ] business voter rosters

    			[ ] business rosters
    				[ ] build a businesses roster by
    					merging rosters from multiple businesses

    				[ ] ask bussinesses for a roster of businesses
    					where vote fraction >= .1%

    					[ ] if someone gives a fake roster,
    						temporary block that address.